@@ -1,7 +1,7 @@
 __author__ = """Martronic SA"""
 __docformat__ = 'plaintext'
 
-PRODUCT_DEPENDENCIES = ['Solgema.ContextualContentMenu',]
+PRODUCT_DEPENDENCIES = ['Solgema.ContextualContentMenu', 'plone.app.z3cform', 'collective.js.jqueryui']
 
 from zope.i18nmessageid import MessageFactory
 _ = MessageFactory('Solgema.fullcalendar')
