@@ -16,3 +16,10 @@ def handleProfileImportedEvent(event):
     topic_methods = topic_type.view_methods
     if 'solgemafullcalendar_view' not in topic_methods:
         topic_type.manage_changeProperties(view_methods=topic_methods+tuple(['solgemafullcalendar_view',]))
+
+    if 'collective.js.jqueryui' in event.profile_id and event.full_import:
+        portal_setup = getToolByName(context, 'portal_setup')
+        try:
+            portal_setup.runAllImportStepsFromProfile('profile-Solgema.fullcalendar:default')
+        except:
+            pass
