@@ -250,19 +250,14 @@ function readCookie(name) {
     openDisplayForm: function (fcevent, event) {
       event.preventDefault();
       var url = fcevent['url'];
-      if (SolgemaFullcalendarVars.ploneVersion.substring(0,1)>3) {
-        var extra = '';
-        var data = {'ajax_load':1};
-      } else {
-        var eventClasses = fcevent['className'];
-        for (var x = 0; x < eventClasses.length; x++) {
-          if (eventClasses[x].search('type-') != -1) {
-            var portalType = eventClasses[x].substring(5, eventClasses[x].length).toLowerCase();
-          }
+      var eventClasses = fcevent['className'];
+      for (var x = 0; x < eventClasses.length; x++) {
+        if (eventClasses[x].search('type-') != -1) {
+          var portalType = eventClasses[x].substring(5, eventClasses[x].length).toLowerCase();
         }
-        var extra = '/SFLight_'+portalType+'_view';
-        var data = {};
       }
+      var extra = '/SFLight_'+portalType+'_view';
+      var data = {};
       jq('#kss-spinner').show();
       var $dialogContent = jq("#event_edit_container");
       $dialogContent.empty();
